#ifndef NAVBUTTON_H
#define NAVBUTTON_H

#include <QAbstractButton>
#include <QMouseEvent>
#include <QPaintEvent>

class NavButton : public QAbstractButton
{
    Q_OBJECT

public:
    explicit NavButton(const QString &text, const QString &iconSource, QWidget *parent = 0);

protected:
    void paintEvent(QPaintEvent *event);

private:
    QImage m_icon;
};

#endif // NAVBUTTON_H
